'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _TextField = require('material-ui/TextField');

var _TextField2 = _interopRequireDefault(_TextField);

var _reactSsFormHandler = require('react-ss-form-handler');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var typingTimer;

var TextInput = _react2.default.createClass({
    displayName: 'TextInput',

    propTypes: {
        name: _react2.default.PropTypes.string.isRequired,
        layoutStyle: _react2.default.PropTypes.oneOf(_reactSsFormHandler.AvailableFormLayoutStyles),
        defaultValue: _react2.default.PropTypes.oneOfType([_react2.default.PropTypes.string, _react2.default.PropTypes.number])
    },
    getInitialState: function getInitialState() {
        return {
            value: this.props.defaultValue,
            previousValue: this.props.defaultValue
        };
    },
    componentWillMount: function componentWillMount() {
        if (this.props.formId) {
            _reactSsFormHandler.FormHandler.initializeInput(this.props.formId, this.props.name, this.props.defaultValue);
        }
    },
    _onDoneTyping: function _onDoneTyping(value) {
        this.props.onDoneTyping(value);
    },
    _onKeyUp: function _onKeyUp(event) {
        if (this.props.onDoneTyping) {
            var value = event.nativeEvent.target.value;
            if (value !== this.state.previousValue) {
                clearTimeout(typingTimer);
                typingTimer = setTimeout(this._onDoneTyping.bind(this, value), this.props.doneTypingInterval || 1000);
            }
        }
    },
    _onKeyDown: function _onKeyDown() {
        clearTimeout(typingTimer);
    },
    _onChange: function _onChange(event) {

        var value = event.nativeEvent.target.value;

        if (this.props._valueType === "number") {
            value = Number(value);
        }

        if (this.props.onChange) {
            this.props.onChange(value);
        }

        this.setState({
            value: value,
            previousValue: this.state.value
        });

        if (this.props.formId) {
            _reactSsFormHandler.FormHandler.inputChanged(this.props.formId, this.props.name, value);
        }
    },

    render: function render() {

        var style = this.props.style || {};

        if (this.props.layoutStyle) {
            _.extend(style, _reactSsFormHandler.FormLayoutStyles[this.props.layoutStyle]);
        }

        return _react2.default.createElement(
            'div',
            { style: style },
            _react2.default.createElement(_TextField2.default, {
                fullWidth: true,
                onChange: this._onChange,
                name: this.props.name,
                placeholder: null,
                type: this.props.type ? this.props.type : 'text',
                hintText: this.props.placeholder,
                floatingLabelText: this.props.label,
                errorText: this.props.errorText,
                onKeyDown: this._onKeyDown,
                onKeyUp: this._onKeyUp,
                inputStyle: this.props.inputStyle,
                hintStyle: this.props.hintStyle,
                underlineShow: this.props.underlineShow,
                defaultValue: this.props.defaultValue
            })
        );
    }
});

exports.default = TextInput;